pub struct FeatureName {
pub kind: FeatureKind,
pub bit_number: u8,
pub feature_name: String,
}Expand description
A struct representing a feature/name pair
Fields
kind: FeatureKindThe type of feature being named
bit_number: u8The bit number within the feature being named, with 0 being the least significant bit
feature_name: StringThe name of the feature pointed to by the feature kind and the bit number