L2Entry

Struct L2Entry 

pub struct L2Entry {
    pub cluster_descriptor: ClusterDescriptor,
    pub is_compressed: bool,
    pub is_used: bool,
}
An entry in an L2 table that can be used to lookup the location and properties of the cluster

Fields

cluster_descriptor: ClusterDescriptor

A descriptor providing the information needed to read from the given cluster

is_compressed: bool

true if the contents of the cluster are compressed using a method specified by the field Version3Header::compression_type, otherwise defaulting to CompressionType::Zlib, which can also be specified via CompressionType::default.

is_used: bool

Set to false for clusters that are unused, compressed or require COW. Set to true for standard clusters whose refcount is exactly one. This information is only accurate in L2 tables that are reachable from the active L1 table.

With external data files, all guest clusters have an implicit refcount of 1 (because of the fixed host = guest mapping for guest cluster offsets), so this bit should be 1 for all allocated clusters.

Implementations

Source

impl L2Entry

pub fn read_contents( &self, reader: &mut (impl Read + Seek), buf: &mut [u8], comp_type: CompressionType, ) -> Result<()>

Read the contents of a given L2 Entry from reader into buf.